# Recipes

**Coming soon.**

Recipes will be copy-paste solutions for common tasks. Unlike Guides (which explain how things work), Recipes give you working code you can drop into your project.

Planned recipes include:

- Adding a new OAuth provider
- Creating a custom entitlement type
- Setting up usage-based billing
- Adding a new background task
- Implementing rate limits per API key
- GDPR user data export

In the meantime, check out the [Guides](../guides/index.md) for detailed explanations of each FastroAI feature.
